@@ -69,15 +69,8 @@ class SciNoteClient(object):
         )
         self.update_token(token)
 
-    def update_token(self, name, token, refresh_token=None, access_token=None):
+    def update_token(self, token):
         """Update token and save it."""
-        if refresh_token:
-            item = token.find(name=name, refresh_token=refresh_token)
-        elif access_token:
-            item = token.find(name=name, access_token=access_token)
-        else:
-            return
-
         self.access_token = token["access_token"]
         self.refresh_token = token["refresh_token"]
         self.token = token
@@ -90,6 +83,7 @@ class SciNoteClient(object):
             client_secret=self.client_secret,
             token=self.token,
             update_token=self.update_token,
+            token_endpoint=self.server_url + "/oauth/token",
         ) as client:
             return client.request(method, url, json=json)
 
@@ -108,6 +102,7 @@ class SciNoteClient(object):
             client_secret=self.client_secret,
             token=self.token,
             update_token=self.update_token,
+            token_endpoint=self.server_url + "/oauth/token",
             timeout=httpx.Timeout(60.0, connect=10.0),
         )
         tasks = [client.request(method, url) for url in urls]
